summaryrefslogtreecommitdiffstats
path: root/kexi/formeditor/editlistviewdialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/formeditor/editlistviewdialog.h')
-rw-r--r--kexi/formeditor/editlistviewdialog.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kexi/formeditor/editlistviewdialog.h b/kexi/formeditor/editlistviewdialog.h
index 0eb3017b..cfbaadbb 100644
--- a/kexi/formeditor/editlistviewdialog.h
+++ b/kexi/formeditor/editlistviewdialog.h
@@ -27,9 +27,9 @@
class TQFrame;
class TQListView;
class TQListViewItem;
-class KListViewItem;
-class KListView;
-class KListBox;
+class TDEListViewItem;
+class TDEListView;
+class TDEListBox;
class TQListBoxItem;
namespace KoProperty {
@@ -40,12 +40,12 @@ namespace KoProperty {
namespace KFormDesigner {
//! A dialog to edit the contents of a listvuew (KListView or TQListView)
/*! The dialog contains two pages, one to edit columns and one to edit ist items.
KoProperty::Editor is used in columns to edit column properties
(there are two properties not supported by TQt Designer: 'width' and 'resizable').
The user can enter list contents inside the list
- using KListViewItem::setRenameable(). Pixmaps are not yet supported. */
+ using TDEListViewItem::setRenameable(). Pixmaps are not yet supported. */
class KFORMEDITOR_EXPORT EditListViewDialog : public KDialogBase
{
Q_OBJECT
@@ -84,8 +84,8 @@ class KFORMEDITOR_EXPORT EditListViewDialog : public KDialogBase
KoProperty::Editor *m_editor;
KoProperty::Set *m_propSet;
TQFrame *m_contents, *m_column;
- KListBox *m_listbox;
- KListView *m_listview;
+ TDEListBox *m_listbox;
+ TDEListView *m_listview;
TQIntDict<TQToolButton> m_buttons;
};
@@ -40,12 +40,12 @@ namespace KoProperty {
namespace KFormDesigner {
-//! A dialog to edit the contents of a listvuew (KListView or TQListView)
+//! A dialog to edit the contents of a listvuew (TDEListView or TQListView)
/*! The dialog contains two pages, one to edit columns and one to edit ist items.
KoProperty::Editor is used in columns to edit column properties